@@ -31,7 +31,7 @@
 #'   \item{nonzeroweight}{Proportion of routes in each strata with species obervation}
 #'   \item{count}{Vector of counts for the species}
 #'   \item{strat}{Vector of strata to be used in the analysis}
-#'   \item{osber}{Vector of unique observer-route pairings}
+#'   \item{obser}{Vector of unique observer-route pairings}
 #'   \item{year}{Vector of years for each count}
 #'   \item{firstyr}{Vector of indicator variables as to whether an observer was a first year}
 #'   \item{month}{vector of numeric month of observation}
@@ -43,6 +43,17 @@
 #'
 #' @importFrom stats median
 #' @importFrom progress progress_bar
+#'
+#' @name bbsBayes-deprecated
+#' @seealso \code{\link{prepare_jags_data}}
+#' @keywords internal
+NULL
+
+#' @rdname bbsBayes-deprecated
+#' @section \code{prepare_jags_data}:
+#'   For \code{prepare_jags_data()}, use
+#'   \code{prepare_data(sampler = "jags", ...)}.
+#'
 #' @export
 #'
 #' @examples
@@ -87,6 +98,9 @@ prepare_jags_data <- function(strat_data = NULL,
                               quiet = FALSE,
                               ...)
 {
+  .Deprecated(new = "prepare_data",
+              msg = "prepare_jags_data is deprecated in favour of prepare_data(sampler = \"jags\", ...)")
+
   if (is.null(strat_data))
   {
     stop("No data supplied to prepare_jags_data()."); return(NULL)
